@@ -1,4 +1,4 @@
-<TeXmacs|1.99.8>
+<TeXmacs|1.99.9>
 
 <style|<tuple|source|std>>
 
@@ -36,6 +36,8 @@
   document has been produced using> GNU <TeXmacs> (<localize|see>
   <with|font-family|tt|http://www.texmacs.org>).<right-flush>>>>>
 
+  <assign|tm-made|<macro|<with|ornament-color||ornament-shadow-color|<value|color>|ornament-sunny-color|<value|color>|ornament-border|1ln|ornament-shape|rounded|ornament-hpadding|0.5spc|ornament-vpadding|0.5spc|<ornament|<math|\<Backsigma\>>>>>>
+
   <assign|TeX|<macro|<active*|T<rsub|<space|-0.4spc><move|<resize|<with|math-level|0|E>||||0.5fn>|0fn|-0.1fn>><space|-0.4spc>X>>>
 
   <assign|LaTeX|<macro|<active*|L<rsup|<space|-0.8spc><move|A|0fn|-0.1fn>><space|-0.2spc>T<rsub|<space|-0.4spc><move|<resize|<with|math-level|0|E>||||0.5fn>|0fn|-0.1fn>><space|-0.4spc>X>>>
@@ -277,12 +279,16 @@
     </surround>
   </macro>>
 
-  <assign|indivisible|<\macro|body>
+  <assign|vgroup|<\macro|body>
     <\surround|<no-break-start>|<no-break-end><right-flush>>
-      <arg|body>
+      <\with|par-min-penalty|100000000>
+        <arg|body>
+      </with>
     </surround>
   </macro>>
 
+  <assign|indivisible|<value|vgroup>>
+
   \;
 
   <assign|center|<macro|body|<with|par-mode|center|<arg|body>>>>
@@ -373,6 +379,8 @@
 
   <assign|extend|<macro|body|left|bottom|right|top|<style-with|src-compact|none|<resize|<arg|body>|<if|<equal|<arg|left>|>|1l|<minimum|1l|<arg|left>>>|<if|<equal|<arg|bottom>|>|1b|<minimum|1b|<arg|bottom>>>|<if|<equal|<arg|right>|>|1r|<maximum|1r|<arg|right>>>|<if|<equal|<arg|top>|>|1t|<maximum|1t|<arg|top>>>>>>>
 
+  <drd-props|extend|arity|5|accessible|0|length|1|length|2|length|3|length|4>
+
   <assign|extend-right|<macro|body|right|<resize|<arg|body>|||<maximum|1r|<arg|right>>|>>>
 
   <assign|swell|<macro|body|<resize|<arg|body>||<minimum|1b|1fnbot>||<maximum|1t|1fntop>>>>
@@ -422,7 +430,7 @@
 
   <assign|stressed-distance|0.2fn>
 
-  <assign|stressed|<macro|body|<quasi|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<value|stressed-color>|<repeat|<with|color|<unquote|<value|color>>|<arg|x>>|<move|<resize|-|<plus|0.6667l|0.3333r>||<plus|0.3333l|0.6667r>|>||<minus|-0.5ex|<value|stressed-distance>>>>>>|<arg|body>>>>>>
+  <assign|stressed|<macro|body|<quasi|<style-with|src-compact|none|<datoms|<macro|x|<with|color|<value|stressed-color>|<repeat*|<with|color|<unquote|<value|color>>|<arg|x>>|<move|<resize|-|<plus|0.6667l|0.3333r>||<plus|0.3333l|0.6667r>|>||<minus|-0.5ex|<value|stressed-distance>>>>>>|<arg|body>>>>>>
 
   <drd-props|stressed|with-like|yes|arity|1|accessible|all>
 
@@ -520,10 +528,20 @@
     </src-comment>
   </active*>
 
-  <assign|html-div|<macro|name|body|<arg|body>>>
+  <assign|web-title|<macro|title|>>
+
+  <assign|html-tag|<macro|name|body|<arg|body>>>
+
+  <assign|html-attr|<macro|attr|val|body|<arg|body>>>
+
+  <assign|html-div-style|<macro|name|body|<arg|body>>>
+
+  <assign|html-div-class|<macro|name|body|<arg|body>>>
 
   <assign|html-style|<macro|style|body|<arg|body>>>
 
+  <assign|html-class|<macro|style|body|<arg|body>>>
+
   <assign|html-javascript|<macro|script|<small|<colored-frame|pastel
   yellow|<with|font-family|ss|Javascript:
   ><with|font-family|tt|<arg|script>>>>>>
@@ -611,6 +629,14 @@
   <assign|text-spc|<macro|<hspace|<value|text-dots-sep>>>>
 
   <assign|text-dots|<macro|<text-spc>.<text-spc>.<text-spc>.<text-spc>>>
+
+  <assign|indent-par-first|1.5fn>
+
+  <assign|padded-par-par-sep|0.6666fn>
+
+  <assign|math-color|<value|color>>
+
+  <assign|strong-color|<value|color>>
 </body>
 
 <\initial>
