@@ -100,6 +100,7 @@
 					      (!math (longhookrightarrow))))))
   (Backepsilon (!group (mbox (rotatebox (!option "origin=c") "180"
 					"E"))))
+  (Backsigma (!group (mbox (reflectbox (!math "\\Sigma")))))
   (Mho (!group (mbox (rotatebox (!option "origin=c") "180"
 				(!math "\\Omega")))))
   (btimes (!group (mbox (rotatebox (!option "origin=c") "90"
@@ -149,12 +150,47 @@
   (Tau "\\mathrm{T}")
   (Zeta "\\mathrm{Z}")
 
+  ;; symbols from mathabx
+  ;; NOTE: we avoid using the mathabx package because it tends
+  ;; to be badly installed and incompatible with certain styles
+  (divides "\\mathrel{|}")
+  (ndivides "\\mathrel{\\nmid}")
+  (asterisk "\\mathord{*}")
+  (dottimes "\\mathbin{\\dot{\\times}}")
+  (precdot "\\mathrel{\\prec\\!\\!\\cdot")
+
+  ;; negations
+  (nin "\\not\\in")
+  (nni "\\not\\ni")
+  (notni "\\not\\ni")
+  (nequiv (!annotate "\\mathrel{\\not\\equiv}" (equiv)))
+  (nleadsto (!annotate "\\not\\leadsto" (leadsto)))
+  (napproxeq (!annotate "\\mathrel{\\not\\approxeq}" (approxeq)))
+  (nprecapprox (!annotate "\\mathrel{\\not\\precapprox}" (precapprox)))
+  (npreccurlyeq (!annotate "\\mathrel{\\not\\preccurlyeq}" (preccurlyeq)))
+  (npreceqq (!annotate "\\mathrel{\\not\\preceqq}" (preceqq)))
+  (nprecsim (!annotate "\\mathrel{\\not\\precsim}" (precsim)))
+  (nsimeq (!annotate "\\mathrel{\\not\\simeq}" (simeq)))
+  (nsqsubset (!annotate "\\mathrel{\\not\\sqsubset}" (sqsubset)))
+  (nsqsubseteq (!annotate "\\mathrel{\\not\\sqsubseteq}" (sqsubseteq)))
+  (nsqsubseteqq (!annotate "\\mathrel{\\not\\sqsubseteqq}" (sqsubseteqq)))
+  (nsqsupset (!annotate "\\mathrel{\\not\\sqsupset}" (sqsupset)))
+  (nsqsupseteq (!annotate "\\mathrel{\\not\\sqsupseteq}" (sqsupseteq)))
+  (nsqsupseteqq (!annotate "\\mathrel{\\not\\sqsupseteqq}" (sqsupseteqq)))
+  (nsuccapprox (!annotate "\\mathrel{\\not\\succapprox}" (succapprox)))
+  (nsucccurlyeq (!annotate "\\mathrel{\\not\\succcurlyeq}" (succcurlyeq)))
+  (nsucceqq (!annotate "\\mathrel{\\not\\succeqq}" (succeqq)))
+  (nsuccsim (!annotate "\\mathrel{\\not\\succsim}" (succsim)))
+  
   ;; other extra symbols
+  (oempty "\\circ")
   (exterior "\\wedge")
   (Exists "\\exists")
   (bigintwl "\\int")
   (bigointwl "\\oint")
   (of ":")
+  (suchthat ":")
+  (barsuchthat "|")
   (point ".")
   (cdummy "\\cdot")
   (comma "{,}")
@@ -165,10 +201,6 @@
   (nocomma "")
   (noplus "")
   (nosymbol "")
-  (nin "\\not\\in")
-  (nni "\\not\\ni")
-  (notni "\\not\\ni")
-  (nleadsto (!annotate "\\not\\leadsto" (leadsto)))
   (dotminus "\\mathaccent95{-}")
   (dotpm "\\mathaccent95{\\pm}")
   (dotmp "\\mathaccent95{\\mp}")
@@ -197,10 +229,17 @@
   (timesassign "\times\\!\\!=")
   (overassign "/\\!\\!=")
   (backassign "=:")
+  (pplus (mathbin "+\\!\\!\\!\\!+"))
   (lflux "\\ll")
   (gflux "\\gg")
   (colons "\\,:\\,")
   (transtype "\\,:\\!!>")
+  (lebar (mathrel (Yleft)))
+  (gebar (mathrel (Yright)))
+  (leangle (mathrel (angle)))
+  (geangle (mathrel (!group (mbox (reflectbox (!math (angle)))))))
+  (leqangle (mathrel (substack (!append (angle) "\\\\" "-"))))
+  (geqangle (mathrel (!group (mbox (reflectbox (!math (substack (!append (angle) "\\\\" "-"))))))))
   (udots "{\\mathinner{\\mskip1mu\\raise1pt\\vbox{\\kern7pt\\hbox{.}}\\mskip2mu\\raise4pt\\hbox{.}\\mskip2mu\\raise7pt\\hbox{.}\\mskip1mu}}")
   (subsetsim (underset (sim) (subset)))
   (supsetsim (underset (sim) (supset)))
@@ -227,11 +266,13 @@
              (!group (!recurse (TeXmacs))) " " (!translate "text editor") " ("
              (!translate "see") " "
              (url "http://www.texmacs.org") ")"))
+  (tmmade (!recurse (tikzframe (Backsigma))))
   (scheme "{\\sc Scheme}")
   (tmsep  ", ")
   (tmSep  "; ")
   (pari "{\\sc Pari}")
   (qed (!math (Box)))
+  (textdots "...")
 
   ;; Unary macros
   (tmrsub (ensuremath (!append "_{" (textrm 1) "}")))
@@ -365,6 +406,8 @@
   (ontop (genfrac "" "" "0pt" "" 1 2))
   (subindex (index (!append 1 "!" 2)))
   (renderfootnote (footnotetext (!append (tmrsup 1) " " 2)))
+  (tmlinenumber (!append (custombinding 1)
+                         (tmlinenote (footnotesize 1) 2 "0cm")))
 
   ;; Ternary macros
   (tmsession (!group (!append (tt) 3)))
@@ -382,6 +425,12 @@
    (trivlist (!append (item (!option (!append (color "rgb:black,10;red,9;green,4;yellow,2") 1)))
 		      (mbox "") (!group (!append (color "blue!50!black") 2))
 		      (item (!option "")) (mbox "") 3)))
+  (tmlinenote
+   (!append (tmdummy)
+            (marginpar (adjustbox
+                        (!append "right=0cm, lap=" 2
+                                 "-\\textwidth-\\marginparsep, raise=" 3)
+                        1))))
   (subsubindex (index (!append 1 "!" 2 "!" 3)))
   (tmref 1)
   (glossaryentry (!append (item (!option (!append 1 (hfill)))) 2 (dotfill) 3))
@@ -448,6 +497,8 @@
             (endgroup)))
   ("tmindent"
    ((!begin "tmparmod" "1.5em" "0pt" "0pt") ---))
+  ("tmlisting"
+   ((!begin "linenumbers") (!append (resetlinenumber) ---)))
   ("elsequation" ((!begin "eqnarray") (!append --- "&&")))
   ("elsequation*" ((!begin "eqnarray*") (!append --- "&&")))
   ("theglossary"
@@ -489,6 +540,7 @@
 (latex-texmacs-description "descriptionaligned")
 (latex-texmacs-description "descriptiondash")
 (latex-texmacs-description "descriptionlong")
+(latex-texmacs-description "descriptionparagraphs")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Extra preamble definitions which are needed to export certain macros
@@ -501,6 +553,13 @@
 			       "hidealllines=true,\ninnerleftmargin=0pt,"
 			       "innerrightmargin=0pt,innertopmargin=0pt,"
 			       "innerbottommargin=0pt" )) "\n"))
+  (tikzframe
+   (!append
+    (!ignore (tikz))
+    "\\newcommand{\\tikzframe}[1]{%\n"
+    "  \\tikz[baseline=(X.base)]\n"
+    "  \\node[draw=black,semithick,rectangle,inner sep=2pt,rounded corners=2pt]\n"
+    "  (X) {#1};}\n"))
   (tmkeywords
    (!append (newcommand (tmkeywords)
 			(!append (textbf (!translate "Keywords:")) " "))
@@ -553,6 +612,13 @@
   (mho
    (!append
     "\\renewcommand{\\mho}{\\mbox{\\rotatebox[origin=c]{180}{$\\omega$}}}"))
+  (custombinding
+   (!append
+    "\\newcounter{tmcounter}\n"
+    "\\newcommand{\\custombinding}[1]{%\n"
+    "  \\setcounter{tmcounter}{#1}%\n"
+    "  \\addtocounter{tmcounter}{-1}%\n"
+    "  \\refstepcounter{tmcounter}}\n"))
   (tmfloat
    (!append
     (!ignore (ifthenelse) (captionof) (widthof))
@@ -613,9 +679,18 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define-macro (latex-texmacs-thmenv prim name before after)
-  `(smart-table latex-texmacs-env-preamble
-     (,prim (!append ,@before (newtheorem ,prim (!translate ,name))
-		     ,@after "\n"))))
+  (let* ((prim* (string-append prim "*"))
+         (nonum (string-append "nn" prim))
+         (thenonum (string-append "\\the" nonum)))
+    `(smart-table latex-texmacs-env-preamble
+       (,prim  (!append ,@before
+                        (newtheorem ,prim (!translate ,name))
+                        ,@after "\n"))
+       (,prim* (!append (newcounter ,nonum) "\n"
+                        "\\def" ,thenonum "{\\unskip}\n"
+                        ,@before
+                        (newtheorem ,prim* (!option ,nonum) (!translate ,name))
+                        ,@after "\n")))))
 
 (define-macro (latex-texmacs-theorem prim name)
   `(latex-texmacs-thmenv ,prim ,name () ()))
