@@ -220,24 +220,27 @@
 
 (menu-bind document-style-extra-menu
   (:require (style-has? "beamer-style"))
-  (=> "Beamer theme"
+  (-> "Beamer theme"
       (for (theme (beamer-themes))
         ((check (eval (upcase-first theme)) "v" (has-style-package? theme))
          (add-style-package theme)))))
 
 (tm-menu (focus-style-extra-menu t)
   (:require (style-has? "beamer-style"))
-  (=> "Beamer theme"
+  (-> "Beamer theme"
       (for (theme (beamer-themes))
         ((check (eval (upcase-first theme)) "v" (has-style-package? theme))
-         (add-style-package theme)))))
+         (add-style-package theme))))
+  (-> "Background color"
+      (link document-background-color-menu)))
 
 (tm-menu (focus-style-extra-icons t)
   (:require (style-has? "beamer-style"))
   (=> (balloon (eval (upcase-first (current-beamer-theme))) "Beamer theme")
       (for (theme (beamer-themes))
         ((check (eval (upcase-first theme)) "v" (has-style-package? theme))
-         (add-style-package theme)))))
+         (add-style-package theme))))
+  (link focus-background-color-icons))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Propose insertion of 'screens' tag in beamer style
@@ -252,11 +255,25 @@
         (begin
           (tree-assign! t `(document ,(tree-ref t 0)
                                      (screens (shown (document ,@(cdr l))))))
-          (if (!= (car p) 0)
+          (if (and p (!= (car p) 0))
               (apply tree-go-to `(,t 1 0 0 ,(- (car p) 1) ,@(cdr p)))))
         (begin
           (tree-assign! t `(document (screens (shown (document ,@l)))))
-          (apply tree-go-to `(,t 0 0 0 ,@p))))))
+          (if p (apply tree-go-to `(,t 0 0 0 ,@p)))))))
+
+(tm-define (remove-single-screens)
+  (let* ((t (buffer-tree))
+         (l (tree-children t)))
+    (when (tree-func? (cAr l) 'screens 1)
+      (when (tree-func? (tree-ref (cAr l) 0) 'shown 1)
+        (let* ((d (tree-ref (tree-ref (cAr l) 0) 0))
+               (b (tree->path t))
+               (p (cursor-inside? d)))
+          (when (tree-func? d 'document)
+            (with q (and (pair? p)
+                         (cons (+ (car p) (length (cDr l))) (cdr p)))
+              (tree-assign! t `(document ,@(cDr l) ,@(tree-children d)))
+              (if q (delayed (:idle 1) (go-to-path (append b q)))))))))))
 
 (tm-define (document-propose-screens?)
   (and (style-has? "beamer-style")
@@ -264,7 +281,7 @@
 
 (tm-menu (focus-document-extra-menu t)
   (:require (document-propose-screens?))
-  ("Screens" (make-switch 'screens)))
+  ("Screens" (make-screens)))
 
 (tm-menu (focus-document-extra-icons t)
   (:require (document-propose-screens?))
@@ -272,6 +289,12 @@
     ((balloon "Screens" "Make a multi-slide presentation")
      (make-screens))))
 
+(tm-define (notify-new-style style)
+  (former style)
+  (if (style-has? "beamer-style")
+      (if (not (screens-buffer?)) (make-screens))
+      (if (screens-buffer?) (remove-single-screens))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Slide titles
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -366,6 +389,7 @@
           (vlist
             ("Color" (interactive-color setter (list)))
             ("Pattern" (open-pattern-selector setter "1cm"))
+            ("Picture" (open-background-picture-selector setter))
             (glue #f #t 0 0))))
       ======
       (explicit-buttons
@@ -418,6 +442,12 @@
   (=> (balloon (eval (upcase-first (get-init "page-type")))
                "Paper size")
       (link document-page-size-menu))
+  (=> (balloon (eval (upcase-first (font-family-main (get-init "font"))))
+               "Main document font")
+      (link document-short-font-menu))
+  (=> (balloon (eval (string-append (get-init "font-base-size") "pt"))
+               "Font size")
+      (link document-font-base-size-menu))
   (=> (balloon (icon (eval (current-page-icon))) "Page layout")
       (link page-rendering-menu))
   (assuming (focus-has-preferences? t)
